unit Unit1;

interface

uses
  Windows, SysUtils, Classes, Graphics, Controls, Forms, StdCtrls, ExtCtrls;

type
  TMainDemo = class(TForm)
    TimerRC: TTimer;
    stCode3: TStaticText;
    lbCodeName2: TLabel;
    lbCodeName: TLabel;
    lbInitialize: TLabel;
    stCode1: TStaticText;
    cbWdmDevice: TComboBox;
    lbWdmDevice: TLabel;
    bnClose: TButton;
    lbRemoteType: TLabel;
    stRemoteType: TStaticText;
    lbCodeExName: TLabel;
    stCode2: TStaticText;
    procedure FormCreate(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure TimerRCTimer(Sender: TObject);
    procedure cbWdmDeviceChange(Sender: TObject);
    procedure bnCloseClick(Sender: TObject);
  private
    m_bCardInited : BOOL;
    { Private declarations }
    procedure OpenBeholderCard(nIndex : Longint);
  public
    { Public declarations }
  end;

var
  MainDemo: TMainDemo;

implementation

{$R *.dfm}

uses
  BeholdRC_Api;

var
  g_nRCT : eRCT;

procedure TMainDemo.OpenBeholderCard(nIndex : Longint);
const
  CsInitRes : String = 'Behold TV card initialize: ';
begin
  TimerRC.Enabled := False;

  m_bCardInited := OpenCard( ULONG(nIndex) );

  if (not m_bCardInited) then begin
    lbInitialize.Caption := CsInitRes + 'Failed!';
    lbInitialize.Font.Color := clMaroon;
  end
    else begin
      lbInitialize.Caption := CsInitRes + 'Success!';
      lbInitialize.Font.Color := clNavy;

      g_nRCT := GetRemoteType();
      case g_nRCT of
       RCT_BUTTONS_30 : stRemoteType.Caption := '30 buttons';
       RCT_BUTTONS_28 : stRemoteType.Caption := '28 buttons';
       RCT_BUTTONS_34 : stRemoteType.Caption := '34 buttons';
      else              stRemoteType.Caption := 'Unknown!!!';
      end;

      TimerRC.Enabled := True;
    end;
end;

procedure TMainDemo.FormCreate(Sender: TObject);
var
  ulIdx     : ULONG;
  szDevName : String;
begin
  if (ulCardCount = 0) then begin
    cbWdmDevice.Items.Add('< WDM device not found >');
    cbWdmDevice.Enabled := False;
  end
    else begin
      cbWdmDevice.Items.BeginUpdate();
      try
        for ulIdx := 0 to ulCardCount - 1 do begin
          szDevName := String(GetCardName(ulIdx));
          cbWdmDevice.Items.Add(szDevName);
        end;
      finally
        cbWdmDevice.Items.EndUpdate();
      end;
      OpenBeholderCard(0);
    end;

  cbWdmDevice.ItemIndex := 0;
end;


procedure TMainDemo.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  TimerRC.Enabled := False;
end;

procedure TMainDemo.TimerRCTimer(Sender: TObject);
var
  ulCodeRC   : ULONG;
  ulCodeExRC : ULONG;
  szNameRC   : String;
begin
  if (not m_bCardInited) then Exit;
  
  ulCodeRC   := GetRemoteCode();
  ulCodeExRC := GetRemoteCodeEx();

  if (g_nRCT = RCT_BUTTONS_30) then begin
    case ulCodeRC of
     $00 : szNameRC := 'Button 0';
     $01 : szNameRC := 'Button 1';
     $02 : szNameRC := 'Button 2';
     $03 : szNameRC := 'Button 3';
     $04 : szNameRC := 'Button 4';
     $05 : szNameRC := 'Button 5';
     $06 : szNameRC := 'Button 6';
     $07 : szNameRC := 'Button 7';
     $08 : szNameRC := 'Button 8';
     $09 : szNameRC := 'Button 9';
     $0A : szNameRC := 'Recall';
     $0B : szNameRC := 'Up';
     $0C : szNameRC := 'Right';
     $0D : szNameRC := 'Mode';
     $0E : szNameRC := 'Sleep';
     $0F : szNameRC := 'Audio';
     $10 : szNameRC := 'Info';
     $11 : szNameRC := 'TV/AV';
     $12 : szNameRC := 'Power';
     $13 : szNameRC := 'Mute';
     $14 : szNameRC := 'Menu';
     $15 : szNameRC := 'Down';
     $16 : szNameRC := 'OK';
     $17 : szNameRC := '+100';
     $18 : szNameRC := 'Left';
     $1A : szNameRC := 'Chan +';
     $1B : szNameRC := 'Vol +';
     $1C : szNameRC := 'Function';
     $1E : szNameRC := 'Chan -';
     $1F : szNameRC := 'Vol -';
    else   szNameRC := 'None';
    end;
  end
    else if (g_nRCT = RCT_BUTTONS_28) then begin
      case ulCodeRC of
       $00 : szNameRC := 'Button 0';
       $01 : szNameRC := 'Button 1';
       $02 : szNameRC := 'Button 2';
       $03 : szNameRC := 'Button 3';
       $04 : szNameRC := 'Button 4';
       $05 : szNameRC := 'Button 5';
       $06 : szNameRC := 'Button 6';
       $07 : szNameRC := 'Button 7';
       $08 : szNameRC := 'Button 8';
       $09 : szNameRC := 'Button 9';
       $0A : szNameRC := 'Recall';
       $0B : szNameRC := 'CH UP';
       $0C : szNameRC := 'VOL+';
       $0D : szNameRC := 'Stereo';
       $0E : szNameRC := 'STOP';
       $0F : szNameRC := 'PREV';
       $10 : szNameRC := 'ZOOM';
       $11 : szNameRC := 'Source';
       $12 : szNameRC := 'Power';
       $13 : szNameRC := 'Mute';
       $15 : szNameRC := 'CH DOWN';
       $18 : szNameRC := 'VOL-';
       $19 : szNameRC := 'SNAPSHOT';
       $1A : szNameRC := 'NEXT';
       $1B : szNameRC := 'TIME SHIFT';
       $1C : szNameRC := 'FM Radio';
       $1D : szNameRC := 'REC';
       $1E : szNameRC := 'PAUSE';
      else   szNameRC := 'None';
      end;
    end
      else if (g_nRCT = RCT_BUTTONS_34) then begin
        case ulCodeRC of
         $00 : szNameRC := 'Button 0';
         $01 : szNameRC := 'Button 1';
         $02 : szNameRC := 'Button 2';
         $03 : szNameRC := 'Button 3';
         $04 : szNameRC := 'Button 4';
         $05 : szNameRC := 'Button 5';
         $06 : szNameRC := 'Button 6';
         $07 : szNameRC := 'Button 7';
         $08 : szNameRC := 'Button 8';
         $09 : szNameRC := 'Button 9';
         $0A : szNameRC := 'Recall';
         $0B : szNameRC := 'Ch Up';
         $0C : szNameRC := 'Vol +';
         $0D : szNameRC := 'Info';
         $0E : szNameRC := 'Teletext';
         $0F : szNameRC := 'Record';
         $10 : szNameRC := 'Full screen';
         $11 : szNameRC := 'Mute';
         $12 : szNameRC := 'Power';
         $13 : szNameRC := 'Preview';
         $14 : szNameRC := 'Aspect';
         $15 : szNameRC := 'Ch Down';
         $16 : szNameRC := 'OK';
         $17 : szNameRC := 'Mode';
         $18 : szNameRC := 'Vol -';
         $19 : szNameRC := 'DVB';
         $1A : szNameRC := 'Stop';
         $1B : szNameRC := 'Play/Pause';
         $1C : szNameRC := 'TV/FM';
         $1D : szNameRC := 'Sleep';
         $1E : szNameRC := 'Source';
         $1F : szNameRC := 'Audio';
         $58 : szNameRC := 'Snapshot';
         $5C : szNameRC := 'Freeze';
        else   szNameRC := 'None';
        end;
      end
        else
          szNameRC := '???';

  stCode1.Caption := Format('0x%.2X', [ulCodeRC]);
  stCode2.Caption := Format('0x%.8X', [ulCodeExRC]);
  stCode3.Caption := szNameRC;
end;

procedure TMainDemo.cbWdmDeviceChange(Sender: TObject);
begin
  OpenBeholderCard(cbWdmDevice.ItemIndex);
end;

procedure TMainDemo.bnCloseClick(Sender: TObject);
begin
  Close();
end;

end.
